@@ -1,5 +1,5 @@
 domain_request_method = {
-    'forbes.com': 'request_normal',
+    'fiverr.com': 'request_normal',
 }
 
 
